@@ -1,7 +1,8 @@
 pub use crate::lua::*;
 pub use crate::types::{LuaCFunction, LuaInteger, LuaNumber, LuaState, LuaString};
+pub use crate::userdata::{Angle, Vector};
 
 pub use crate::util::dump_stack;
-pub use crate::{cstr, printgm, reg, rstr, try_cstr, try_rstr};
+pub use crate::{cstr, printgm, reg, rstr, try_cstr, try_rstr, iface};
 
 pub use rglua_macros::{gmod_close, gmod_open, lua_function};
